<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>CreateFieldDialog</name>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1049"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1062"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1072"/>
        <source>String</source>
        <translation>Chaine de caractères</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1073"/>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1074"/>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1075"/>
        <source>Number</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1076"/>
        <source>Phone Number</source>
        <translation>Téléphone</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1077"/>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1078"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="1083"/>
        <source>Order</source>
        <translation>Ordre</translation>
    </message>
</context>
<context>
    <name>DetailWindow</name>
    <message>
        <location filename="../../DetailedWindow.cpp" line="63"/>
        <source>Copy of </source>
        <translation>Copie de </translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="110"/>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="112"/>
        <location filename="../../DetailedWindow.cpp" line="739"/>
        <location filename="../../DetailedWindow.cpp" line="752"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="113"/>
        <source>Change Face Pict.</source>
        <translation>Modifier le recto de l&apos;image</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="114"/>
        <source>Mirror Face Pict.</source>
        <translation>Retourner le recto de l&apos;image</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="115"/>
        <source>Change Back Pict.</source>
        <translation>Modifier le verso de l&apos;image</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="116"/>
        <source>Mirror Back Pict.</source>
        <translation>Retourner le verso de l&apos;image</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="117"/>
        <source>Delete Face Pict.</source>
        <translation>Supprimer le recto de l&apos;image</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="118"/>
        <source>Delete Back Pict.</source>
        <translation>Supprimer le verso de l&apos;image</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="119"/>
        <source>Modify fields</source>
        <translation>Modifier les champs</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="124"/>
        <source>New Card</source>
        <translation>Nouvelle carte</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="125"/>
        <source>Edit Card</source>
        <translation>Editer la carte</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="126"/>
        <source>New Card like this</source>
        <translation>Nouvelle carte comme celle-ci</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="127"/>
        <source>Duplicate Card</source>
        <translation>Dupliquer la carte</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="128"/>
        <source>Export Face Pict.</source>
        <translation>Exporter le recto de l&apos;image</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="129"/>
        <source>Export Back Pict.</source>
        <translation>Exporter le verso de l&apos;image</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="156"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="167"/>
        <source>Group Name</source>
        <translation>Nom du groupe</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="185"/>
        <source>Membership Info</source>
        <translation>Information adhésion</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="186"/>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="187"/>
        <source>Credit Card</source>
        <translation>Carte de crédit</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="188"/>
        <source>Bank Account</source>
        <translation>Compte bancaire</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="189"/>
        <source>Health Numbers</source>
        <translation>Numéros de santé</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="190"/>
        <source>Passport Info</source>
        <translation>Information passeport</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="191"/>
        <source>Note Card</source>
        <translation>Notes diverses</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="192"/>
        <source>Car Info</source>
        <translation>Information véhicule</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="193"/>
        <source>Cellular Phone</source>
        <translation>Mobile</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="194"/>
        <source>Serial Number Software</source>
        <translation>Descriptif logiciel</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="195"/>
        <source>Serial Number Hardware</source>
        <translation>Descriptif matériel</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="196"/>
        <source>Web site</source>
        <translation>Site internet</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="197"/>
        <source>ID Card</source>
        <translation>Carte d&apos;identité</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="198"/>
        <source>Social Security Number</source>
        <translation>Numéro de sécurité sociale</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="199"/>
        <source>Email Account</source>
        <translation>Compte de messagerie internet</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="200"/>
        <source>Driver&apos;s License</source>
        <translation>Permis de conduire</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="201"/>
        <source>Others</source>
        <translation>Autres</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="205"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="473"/>
        <location filename="../../DetailedWindow.cpp" line="519"/>
        <source>Click to see</source>
        <translation>Cliquer pour voir</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="573"/>
        <source>Card description is missing</source>
        <translation>La description de la carte est manquante</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="583"/>
        <source>Type card is missing</source>
        <translation>Le type de la carte est manquant</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="737"/>
        <location filename="../../DetailedWindow.cpp" line="750"/>
        <source>Edit</source>
        <translation>Editer</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="738"/>
        <location filename="../../DetailedWindow.cpp" line="751"/>
        <source>Mirror</source>
        <translation>Retourner</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="742"/>
        <source>Export Face</source>
        <translation>Exporter le recto</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="755"/>
        <source>Export Back</source>
        <translation>Exporter le verso</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="773"/>
        <source>Choose card face image file</source>
        <translation>Choisir le fichier image pour le recto de la carte</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="775"/>
        <location filename="../../DetailedWindow.cpp" line="913"/>
        <source>Images (*.png);;</source>
        <translation>Images (*.png);</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="787"/>
        <source>Choose card face image</source>
        <translation>Choisir l&apos;image pour le recto de la carte</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="789"/>
        <location filename="../../DetailedWindow.cpp" line="928"/>
        <source>Images (*.png *.jpg *.gif *.jpeg);;</source>
        <translation>Images (*.png *.jpg *.gif *.jpeg);</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="911"/>
        <source>Choose card back image file</source>
        <translation>Choisir le fichier image pour le verso de la carte</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="926"/>
        <source>Choose card back image</source>
        <translation>Choisir l&apos;image pour le verso de la carte</translation>
    </message>
    <message>
        <location filename="../../DetailedWindow.cpp" line="966"/>
        <source>Are you sure you want to discard changes?</source>
        <translation>Etes-vous sûr de vouloir annuler les modifications ?</translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <location filename="../../LoginDialog.cpp" line="97"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="105"/>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="149"/>
        <source>About</source>
        <translation>A propos de</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="157"/>
        <source>Donate</source>
        <translation>Faire un don</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="165"/>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="221"/>
        <source>About Wallet</source>
        <translation>A propos de Wallet</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="239"/>
        <source>Password is required</source>
        <translation>Un mot de passe est requis</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="256"/>
        <source>For verification, please, enter your password again</source>
        <translation>Pour vérification, SVP, entrez à nouveau votre mot de passe</translation>
    </message>
    <message>
        <location filename="../../LoginDialog.cpp" line="269"/>
        <source>Invalid password, please enter again</source>
        <translation>Mot de passe invalide, resaisissez-le SVP</translation>
    </message>
</context>
<context>
    <name>RenameGroupDialog</name>
    <message>
        <location filename="../../eWallet.cpp" line="49"/>
        <source>Save &amp;&amp; Close</source>
        <translation>Enregistrer &amp;&amp; Fermer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="62"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
</context>
<context>
    <name>eWallet</name>
    <message>
        <location filename="../../eWallet.cpp" line="366"/>
        <location filename="../../eWallet.cpp" line="819"/>
        <source>&lt;All&gt;</source>
        <translation>&lt;Tout&gt;</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="385"/>
        <location filename="../../eWallet.cpp" line="828"/>
        <source>&lt;No Group&gt;</source>
        <translation>&lt;Pas de groupe&gt;</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="444"/>
        <source>Are you sure you want to remove all your data? You will lost all your data</source>
        <translation>Etes-vous sûr de vouloir supprimer toutes vos données ? Vous perdrez toutes vos données</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="469"/>
        <source>Wrong password</source>
        <translation>Mot de passe erroné</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="529"/>
        <source>Organization</source>
        <translation>Organisation</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="530"/>
        <location filename="../../eWallet.cpp" line="551"/>
        <location filename="../../eWallet.cpp" line="601"/>
        <source>Phone Number</source>
        <translation>Téléphone</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="531"/>
        <location filename="../../eWallet.cpp" line="565"/>
        <source>Other Information</source>
        <translation>Autre information</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="532"/>
        <location filename="../../eWallet.cpp" line="541"/>
        <location filename="../../eWallet.cpp" line="643"/>
        <source>User Name</source>
        <translation>Nom utilisateur</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="533"/>
        <location filename="../../eWallet.cpp" line="542"/>
        <location filename="../../eWallet.cpp" line="569"/>
        <location filename="../../eWallet.cpp" line="600"/>
        <location filename="../../eWallet.cpp" line="629"/>
        <location filename="../../eWallet.cpp" line="640"/>
        <location filename="../../eWallet.cpp" line="644"/>
        <location filename="../../eWallet.cpp" line="653"/>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="534"/>
        <source>Organization club</source>
        <translation>Club</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="535"/>
        <location filename="../../eWallet.cpp" line="568"/>
        <location filename="../../eWallet.cpp" line="634"/>
        <source>ID Number</source>
        <translation>Identifiant</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="536"/>
        <location filename="../../eWallet.cpp" line="543"/>
        <location filename="../../eWallet.cpp" line="608"/>
        <location filename="../../eWallet.cpp" line="627"/>
        <location filename="../../eWallet.cpp" line="652"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="537"/>
        <location filename="../../eWallet.cpp" line="557"/>
        <location filename="../../eWallet.cpp" line="571"/>
        <location filename="../../eWallet.cpp" line="646"/>
        <location filename="../../eWallet.cpp" line="656"/>
        <source>Card Notes</source>
        <translation>Notes</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="540"/>
        <location filename="../../eWallet.cpp" line="645"/>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="546"/>
        <source>Credit Card Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="547"/>
        <source>Card Provider</source>
        <translation>Organisme</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="548"/>
        <source>Card Number</source>
        <translation>Numéro</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="549"/>
        <location filename="../../eWallet.cpp" line="554"/>
        <location filename="../../eWallet.cpp" line="651"/>
        <source>Expiration Date</source>
        <translation>Expire le</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="550"/>
        <source>Name on Card</source>
        <translation>Nom du porteur</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="552"/>
        <location filename="../../eWallet.cpp" line="563"/>
        <source>PIN</source>
        <translation>Code personnel</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="553"/>
        <source>Start Date</source>
        <translation>Mise en service le</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="555"/>
        <source>Detail</source>
        <translation>Détail</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="556"/>
        <source>3-digit CVC#</source>
        <translation>Cryptogramme</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="560"/>
        <source>Bank Name</source>
        <translation>Nom de la banque</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="561"/>
        <source>Account Number</source>
        <translation>Numéro de compte</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="562"/>
        <source>Telephone</source>
        <translation>Téléphone</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="564"/>
        <source>SWIFT Code</source>
        <translation>Code SWIFT</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="570"/>
        <location filename="../../eWallet.cpp" line="635"/>
        <source>Card Title</source>
        <translation>Titre</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="574"/>
        <source>Passport No</source>
        <translation>Numéro</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="575"/>
        <source>Surname</source>
        <translation>Nom de famille</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="576"/>
        <source>Given names</source>
        <translation>Prénoms</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="577"/>
        <source>Date of birth</source>
        <translation>Date de naissance</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="578"/>
        <source>Date of issue</source>
        <translation>Délivré le</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="579"/>
        <source>Date of expiration</source>
        <translation>Expire le</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="580"/>
        <source>Authority</source>
        <translation>Délivré par</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="583"/>
        <source>Text</source>
        <translation>Texte</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="586"/>
        <location filename="../../eWallet.cpp" line="590"/>
        <source>Model</source>
        <translation>Modèle</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="587"/>
        <source>Vehicle Number</source>
        <translation>Immatriculation</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="591"/>
        <source>Brand</source>
        <translation>Marque</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="592"/>
        <source>IMEI#</source>
        <translation>IMEI#</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="593"/>
        <source>Firmware code</source>
        <translation>Code du firmware </translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="594"/>
        <source>Purchased</source>
        <translation>Acheté le</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="595"/>
        <source>Pin1</source>
        <translation>Code personnel 1</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="596"/>
        <source>Pin2</source>
        <translation>Code personnel 2</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="597"/>
        <source>Puk1</source>
        <translation>Clé de déblocage 1</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="598"/>
        <source>Puk2</source>
        <translation>Clé de déblocage 2</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="599"/>
        <source>Num SIM</source>
        <translation>Numéro carte SIM</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="602"/>
        <source>Manufacturer</source>
        <translation>Fabricant</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="605"/>
        <location filename="../../eWallet.cpp" line="619"/>
        <source>Product</source>
        <translation>Produit</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="606"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="607"/>
        <location filename="../../eWallet.cpp" line="620"/>
        <source>Serial #</source>
        <translation>Numéro de série</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="609"/>
        <source>Company</source>
        <translation>Compagnie</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="610"/>
        <source>Date bought</source>
        <translation>Acheté le</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="611"/>
        <source>Username</source>
        <translation>Nom utilisateur</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="612"/>
        <location filename="../../eWallet.cpp" line="628"/>
        <source>Login</source>
        <translation>Identifiant</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="613"/>
        <source>Authorization key</source>
        <translation>Clé d'autorisation</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="614"/>
        <location filename="../../eWallet.cpp" line="623"/>
        <source>Price paid</source>
        <translation>Tarif</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="615"/>
        <source>Support</source>
        <translation>Support</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="616"/>
        <location filename="../../eWallet.cpp" line="631"/>
        <source>Notes</source>
        <translation>Notes</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="621"/>
        <source>Model #</source>
        <translation>Modèle</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="622"/>
        <source>Bought from</source>
        <translation>Acheté le</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="624"/>
        <source>Guarantee period</source>
        <translation>Fin de garantie</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="630"/>
        <source>E mail used</source>
        <translation>Email utilisé</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="638"/>
        <source>Social Security Number</source>
        <translation>Numéro de sécurité sociale</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="639"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="649"/>
        <source>Driver&apos;s License Number</source>
        <translation>Numéro</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="650"/>
        <source>Date Issued</source>
        <translation>Délivré le</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="908"/>
        <source>About</source>
        <translation>A propos de</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="910"/>
        <source>Delete DB</source>
        <translation>Supprimer BDD</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="912"/>
        <location filename="../../eWallet.cpp" line="923"/>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="915"/>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="917"/>
        <location filename="../../eWallet.cpp" line="1391"/>
        <source>Edit</source>
        <translation>Editer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="918"/>
        <source>Invert Sort</source>
        <translation>Tri inversé</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="919"/>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="920"/>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="922"/>
        <source>Change Password</source>
        <translation>Changer le mot de passe</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="982"/>
        <source>Are you sure you want to remove it?</source>
        <translation>Etes-vous sûr de vouloir le supprimer ?</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1130"/>
        <source>Choose import file</source>
        <translation>Choisir le fichier d&apos;import</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1132"/>
        <location filename="../../eWallet.cpp" line="1407"/>
        <source>Text files (*.txt);;</source>
        <translation>Fichiers texte (*.txt);</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1380"/>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1381"/>
        <location filename="../../eWallet.cpp" line="1394"/>
        <source>Delete</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1390"/>
        <source>View</source>
        <translation>Voir</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1392"/>
        <source>New like this</source>
        <translation>Nouveau comme celui-ci</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1393"/>
        <source>Duplicate</source>
        <translation>Dupliquer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1405"/>
        <source>Choose export file</source>
        <translation>Choisir fichier d&apos;export</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1610"/>
        <source>About Wallet</source>
        <translation>A propos de Wallet</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1645"/>
        <source>Changing password, please wait until application quits</source>
        <translation>Changement du mot de passe en cours, patientez SVP que l&apos;application se ferme</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1651"/>
        <source>Password changed successfully, application will exit</source>
        <translation>Mot de passe modifié avec succès, l&apos;application va se fermer</translation>
    </message>
    <message>
        <location filename="../../eWallet.cpp" line="1653"/>
        <source>Password CANNOT BE changed, because %1, and application will exit</source>
        <translation>Le mot de passe ne peut être modifié, parce que %1 et l&apos;application va se fermer</translation>
    </message>
</context>
</TS>
